@@ -11,13 +11,14 @@
 #include <katebuffer.h>
 #include <kateconfig.h>
 #include <katedocument.h>
-#include <kateglobal.h>
 #include <kateview.h>
 #include <kateviewinternal.h>
 #include <ktexteditor/message.h>
 #include <ktexteditor/movingcursor.h>
 
 #include <QScrollBar>
+#include <QSignalSpy>
+#include <QStandardPaths>
 #include <QTemporaryFile>
 #include <QtTestWidgets>
 
@@ -30,7 +31,7 @@ QTEST_MAIN(KateViewTest)
 KateViewTest::KateViewTest()
     : QObject()
 {
-    KTextEditor::EditorPrivate::enableUnitTestMode();
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 KateViewTest::~KateViewTest()
@@ -154,6 +155,20 @@ void KateViewTest::testLowerCaseBlockSelection()
     QCOMPARE(doc.text(), QStringLiteral("ny\nnyy\n"));
 }
 
+void KateViewTest::testIndentBlockSelection()
+{
+    KTextEditor::DocumentPrivate doc;
+    doc.setText(QStringLiteral("nY\nnYY\n"));
+
+    KTextEditor::ViewPrivate *view1 = new KTextEditor::ViewPrivate(&doc, nullptr);
+    view1->setSelection(Range(0, 0, 2, 0));
+    view1->setBlockSelection(true);
+    view1->indent();
+    QCOMPARE(doc.text(), QStringLiteral("    nY\n    nYY\n    "));
+    view1->unIndent();
+    QCOMPARE(doc.text(), QStringLiteral("nY\nnYY\n"));
+}
+
 namespace
 {
 QWidget *findViewInternal(KTextEditor::View *view)
@@ -472,8 +487,7 @@ void KateViewTest::testDragAndDrop()
     view->setSelection(Range(1, 0, 2, 0));
     QCOMPARE(view->selectionRange(), Range(1, 0, 2, 0));
 
-    (void)QTest::qWaitForWindowExposed(view);
-    QTest::qWait(100); // For whatever reason needed
+    QVERIFY(QTest::qWaitForWindowExposed(view));
 
     const QPoint startDragPos = internalView->mapFrom(view, view->cursorToCoordinate(KTextEditor::Cursor(1, 2)));
     const QPoint endDragPos = internalView->mapFrom(view, view->cursorToCoordinate(KTextEditor::Cursor(3, 0)));
@@ -744,4 +758,34 @@ void KateViewTest::testUpdateFoldingMarkersHighlighting()
     QCOMPARE(foldingMarkerEnd->toRange(), firstDoMatching);
 }
 
+void KateViewTest::testDdisplayRangeChangedEmitted()
+{
+    KTextEditor::DocumentPrivate doc(false, false);
+    doc.setText(QStringList(250, QStringLiteral("Hello world")));
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    view->resize(300, 300);
+    QSignalSpy spy(view, &KTextEditor::View::displayRangeChanged);
+    view->setCursorPosition({180, 0});
+    QVERIFY(spy.count() == 1);
+}
+
+void KateViewTest::testCrashOnPasteInOverwriteMode()
+{
+    // create doc with a few lines
+    KTextEditor::DocumentPrivate doc(false, false);
+    const QString testText(QStringLiteral("test1\ntest2\ntest3\n"));
+    doc.setText(testText);
+
+    // create view in overwrite mode
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    view->doc()->config()->setOvr(true);
+
+    // simulate paste at end of document that did crash, bug 496612
+    view->setCursorPosition(KTextEditor::Cursor(2, 0));
+    view->paste(&testText);
+
+    // check result is ok
+    QCOMPARE(doc.text(), QStringLiteral("test1\ntest2\ntest1\ntest2\ntest3\n"));
+}
+
 // kate: indent-mode cstyle; indent-width 4; replace-tabs on;
