@@ -405,6 +405,7 @@ void KateDocumentConfig::readConfig(const KConfigGroup &config)
         if (onTheFlyChecking) {
             Sonnet::Speller speller;
             speller.setLanguage(Sonnet::Speller().defaultLanguage());
+            speller.isMisspelled(QStringLiteral("dummy to trigger dictionary load"));
             Sonnet::GuessLanguage languageGuesser;
             languageGuesser.identify(QStringLiteral("dummy to trigger identify"));
         }
@@ -567,6 +568,7 @@ KateViewConfig::KateViewConfig()
     addConfigEntry(ConfigEntry(StatusbarLineColumnCompact, "Statusbar Line Column Compact Mode", QString(), true));
     addConfigEntry(ConfigEntry(ShowStatusbarEOL, "Shoe Line Ending Type in Statusbar", QString(), false));
     addConfigEntry(ConfigEntry(EnableAccessibility, "Enable Accessibility", QString(), true));
+    addConfigEntry(ConfigEntry(CycleThroughBookmarks, "Cycle Through Bookmarks", QString(), true));
 
     // Never forget to finalize or the <CommandName> becomes not available
     finalizeConfigEntries();
@@ -738,7 +740,6 @@ void KateRendererConfig::readConfig(const KConfigGroup &config)
 
     // read font, including font features
     auto font = config.readEntry(KEY_FONT, QFontDatabase::systemFont(QFontDatabase::FixedFont));
-#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
     const QStringList rawFeaturesList = config.readEntry(KEY_FONT_FEATURES, QStringList());
     for (const QString &feature : rawFeaturesList) {
         const auto parts = feature.split(QStringLiteral("="), Qt::SkipEmptyParts);
@@ -751,7 +752,6 @@ void KateRendererConfig::readConfig(const KConfigGroup &config)
             }
         }
     }
-#endif
     setFont(font);
 
     // setSchema will default to right theme
@@ -778,7 +778,6 @@ void KateRendererConfig::writeConfig(KConfigGroup &config)
     // write font, including font features
     const auto font = baseFont();
     config.writeEntry(KEY_FONT, font);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
     const auto tags = font.featureTags();
     QStringList features;
     for (const auto &tag : tags) {
@@ -787,7 +786,6 @@ void KateRendererConfig::writeConfig(KConfigGroup &config)
         features.push_back(QStringLiteral("%1=%2").arg(name, QString::number(value)));
     }
     config.writeEntry(KEY_FONT_FEATURES, features);
-#endif
 
     config.writeEntry(KEY_COLOR_THEME, schema());
 
